diff a/test/hotspot/jtreg/serviceability/jvmti/valhalla/GetObjectHashCode/libValueGetObjectHashCodeTest.cpp b/test/hotspot/jtreg/serviceability/jvmti/valhalla/GetObjectHashCode/libValueGetObjectHashCodeTest.cpp
--- /dev/null
+++ b/test/hotspot/jtreg/serviceability/jvmti/valhalla/GetObjectHashCode/libValueGetObjectHashCodeTest.cpp
@@ -0,0 +1,54 @@
+/*
+ * Copyright (c) 2025, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ *
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.
+ *
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
+ *
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
+ */
+
+#include <jvmti.h>
+#include <cstdlib>
+#include <cstring>
+
+namespace {
+jvmtiEnv *jvmti = nullptr;
+
+void checkJvmti(int code, const char* message) {
+  if (code != JVMTI_ERROR_NONE) {
+    printf("Error %s: %d\n", message, code);
+    abort();
+  }
+}
+
+}
+
+extern "C" JNIEXPORT jint JNICALL Java_ValueGetObjectHashCodeTest_getHash0(JNIEnv* jni_env, jclass clazz, jobject object) {
+  jint hash = 0;
+  jvmtiError err = jvmti->GetObjectHashCode(object, &hash);
+  checkJvmti(err, "GetObjectHashCode failed");
+  return hash;
+}
+
+extern "C" JNIEXPORT jint JNICALL Agent_OnLoad(JavaVM *vm, char *options, void *reserved) {
+  if (vm->GetEnv(reinterpret_cast<void **>(&jvmti), JVMTI_VERSION) != JNI_OK || !jvmti) {
+    printf("Could not initialize JVMTI\n");
+    abort();
+  }
+  return JVMTI_ERROR_NONE;
+}
+
